# wasp-general

Collection of unrelated functions and classes widely used in different wasp-projects

## Documentation build tools:
Sphinx with graphviz, autodoc, and viewcode extensions

PyTest status:

[![Build Status](http://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-general)](https://github.com/a1ezzz/wasp-general)

Documentation build status:

[![Build Status](http://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-general-docs)](https://github.com/a1ezzz/wasp-general)

PEP8 compliance (except W191 E266 E265 E731 and maximum length - 119):

[![Build Status](http://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-general-pep8)](https://github.com/a1ezzz/wasp-general)

Online documentation (Read the Docs)

[![Documentation Status](https://readthedocs.org/projects/wasp-general/badge/?version=latest)](http://wasp-general.readthedocs.io/en/latest/?badge=latest)
